# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/distribution/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/distribution/v1beta1/tx.proto',
  package='cosmos.distribution.v1beta1',
  syntax='proto3',
  serialized_options=b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$cosmos/distribution/v1beta1/tx.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x91\x01\n\x15MsgSetWithdrawAddress\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x35\n\x10withdraw_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"withdraw_address\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgSetWithdrawAddressResponse\"\x98\x01\n\x1aMsgWithdrawDelegatorReward\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"$\n\"MsgWithdrawDelegatorRewardResponse\"c\n\x1eMsgWithdrawValidatorCommission\x12\x37\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"(\n&MsgWithdrawValidatorCommissionResponse\"\x90\x01\n\x14MsgFundCommunityPool\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tdepositor\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgFundCommunityPoolResponse2\xc8\x04\n\x03Msg\x12\x84\x01\n\x12SetWithdrawAddress\x12\x32.cosmos.distribution.v1beta1.MsgSetWithdrawAddress\x1a:.cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse\x12\x93\x01\n\x17WithdrawDelegatorReward\x12\x37.cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward\x1a?.cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse\x12\x9f\x01\n\x1bWithdrawValidatorCommission\x12;.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission\x1a\x43.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse\x12\x81\x01\n\x11\x46undCommunityPool\x12\x31.cosmos.distribution.v1beta1.MsgFundCommunityPool\x1a\x39.cosmos.distribution.v1beta1.MsgFundCommunityPoolResponseB7Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_MSGSETWITHDRAWADDRESS = _descriptor.Descriptor(
  name='MsgSetWithdrawAddress',
  full_name='cosmos.distribution.v1beta1.MsgSetWithdrawAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_address', full_name='cosmos.distribution.v1beta1.MsgSetWithdrawAddress.delegator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"delegator_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdraw_address', full_name='cosmos.distribution.v1beta1.MsgSetWithdrawAddress.withdraw_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\027yaml:\"withdraw_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=269,
)


_MSGSETWITHDRAWADDRESSRESPONSE = _descriptor.Descriptor(
  name='MsgSetWithdrawAddressResponse',
  full_name='cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=302,
)


_MSGWITHDRAWDELEGATORREWARD = _descriptor.Descriptor(
  name='MsgWithdrawDelegatorReward',
  full_name='cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='delegator_address', full_name='cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward.delegator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"delegator_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward.validator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"validator_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=457,
)


_MSGWITHDRAWDELEGATORREWARDRESPONSE = _descriptor.Descriptor(
  name='MsgWithdrawDelegatorRewardResponse',
  full_name='cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=495,
)


_MSGWITHDRAWVALIDATORCOMMISSION = _descriptor.Descriptor(
  name='MsgWithdrawValidatorCommission',
  full_name='cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"validator_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=596,
)


_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE = _descriptor.Descriptor(
  name='MsgWithdrawValidatorCommissionResponse',
  full_name='cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=638,
)


_MSGFUNDCOMMUNITYPOOL = _descriptor.Descriptor(
  name='MsgFundCommunityPool',
  full_name='cosmos.distribution.v1beta1.MsgFundCommunityPool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='cosmos.distribution.v1beta1.MsgFundCommunityPool.amount', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depositor', full_name='cosmos.distribution.v1beta1.MsgFundCommunityPool.depositor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=785,
)


_MSGFUNDCOMMUNITYPOOLRESPONSE = _descriptor.Descriptor(
  name='MsgFundCommunityPoolResponse',
  full_name='cosmos.distribution.v1beta1.MsgFundCommunityPoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=817,
)

_MSGFUNDCOMMUNITYPOOL.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgSetWithdrawAddress'] = _MSGSETWITHDRAWADDRESS
DESCRIPTOR.message_types_by_name['MsgSetWithdrawAddressResponse'] = _MSGSETWITHDRAWADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['MsgWithdrawDelegatorReward'] = _MSGWITHDRAWDELEGATORREWARD
DESCRIPTOR.message_types_by_name['MsgWithdrawDelegatorRewardResponse'] = _MSGWITHDRAWDELEGATORREWARDRESPONSE
DESCRIPTOR.message_types_by_name['MsgWithdrawValidatorCommission'] = _MSGWITHDRAWVALIDATORCOMMISSION
DESCRIPTOR.message_types_by_name['MsgWithdrawValidatorCommissionResponse'] = _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['MsgFundCommunityPool'] = _MSGFUNDCOMMUNITYPOOL
DESCRIPTOR.message_types_by_name['MsgFundCommunityPoolResponse'] = _MSGFUNDCOMMUNITYPOOLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgSetWithdrawAddress = _reflection.GeneratedProtocolMessageType('MsgSetWithdrawAddress', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETWITHDRAWADDRESS,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgSetWithdrawAddress)
  })
_sym_db.RegisterMessage(MsgSetWithdrawAddress)

MsgSetWithdrawAddressResponse = _reflection.GeneratedProtocolMessageType('MsgSetWithdrawAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETWITHDRAWADDRESSRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse)
  })
_sym_db.RegisterMessage(MsgSetWithdrawAddressResponse)

MsgWithdrawDelegatorReward = _reflection.GeneratedProtocolMessageType('MsgWithdrawDelegatorReward', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWDELEGATORREWARD,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward)
  })
_sym_db.RegisterMessage(MsgWithdrawDelegatorReward)

MsgWithdrawDelegatorRewardResponse = _reflection.GeneratedProtocolMessageType('MsgWithdrawDelegatorRewardResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWDELEGATORREWARDRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse)
  })
_sym_db.RegisterMessage(MsgWithdrawDelegatorRewardResponse)

MsgWithdrawValidatorCommission = _reflection.GeneratedProtocolMessageType('MsgWithdrawValidatorCommission', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWVALIDATORCOMMISSION,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission)
  })
_sym_db.RegisterMessage(MsgWithdrawValidatorCommission)

MsgWithdrawValidatorCommissionResponse = _reflection.GeneratedProtocolMessageType('MsgWithdrawValidatorCommissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse)
  })
_sym_db.RegisterMessage(MsgWithdrawValidatorCommissionResponse)

MsgFundCommunityPool = _reflection.GeneratedProtocolMessageType('MsgFundCommunityPool', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDCOMMUNITYPOOL,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgFundCommunityPool)
  })
_sym_db.RegisterMessage(MsgFundCommunityPool)

MsgFundCommunityPoolResponse = _reflection.GeneratedProtocolMessageType('MsgFundCommunityPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDCOMMUNITYPOOLRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgFundCommunityPoolResponse)
  })
_sym_db.RegisterMessage(MsgFundCommunityPoolResponse)


DESCRIPTOR._options = None
_MSGSETWITHDRAWADDRESS.fields_by_name['delegator_address']._options = None
_MSGSETWITHDRAWADDRESS.fields_by_name['withdraw_address']._options = None
_MSGSETWITHDRAWADDRESS._options = None
_MSGWITHDRAWDELEGATORREWARD.fields_by_name['delegator_address']._options = None
_MSGWITHDRAWDELEGATORREWARD.fields_by_name['validator_address']._options = None
_MSGWITHDRAWDELEGATORREWARD._options = None
_MSGWITHDRAWVALIDATORCOMMISSION.fields_by_name['validator_address']._options = None
_MSGWITHDRAWVALIDATORCOMMISSION._options = None
_MSGFUNDCOMMUNITYPOOL.fields_by_name['amount']._options = None
_MSGFUNDCOMMUNITYPOOL._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='cosmos.distribution.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=820,
  serialized_end=1404,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetWithdrawAddress',
    full_name='cosmos.distribution.v1beta1.Msg.SetWithdrawAddress',
    index=0,
    containing_service=None,
    input_type=_MSGSETWITHDRAWADDRESS,
    output_type=_MSGSETWITHDRAWADDRESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WithdrawDelegatorReward',
    full_name='cosmos.distribution.v1beta1.Msg.WithdrawDelegatorReward',
    index=1,
    containing_service=None,
    input_type=_MSGWITHDRAWDELEGATORREWARD,
    output_type=_MSGWITHDRAWDELEGATORREWARDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WithdrawValidatorCommission',
    full_name='cosmos.distribution.v1beta1.Msg.WithdrawValidatorCommission',
    index=2,
    containing_service=None,
    input_type=_MSGWITHDRAWVALIDATORCOMMISSION,
    output_type=_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FundCommunityPool',
    full_name='cosmos.distribution.v1beta1.Msg.FundCommunityPool',
    index=3,
    containing_service=None,
    input_type=_MSGFUNDCOMMUNITYPOOL,
    output_type=_MSGFUNDCOMMUNITYPOOLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/store/v1beta1/listening.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/base/store/v1beta1/listening.proto',
  package='cosmos.base.store.v1beta1',
  syntax='proto3',
  serialized_options=b'Z(github.com/cosmos/cosmos-sdk/store/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)cosmos/base/store/v1beta1/listening.proto\x12\x19\x63osmos.base.store.v1beta1\"L\n\x0bStoreKVPair\x12\x11\n\tstore_key\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\x08\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\r\n\x05value\x18\x04 \x01(\x0c\x42*Z(github.com/cosmos/cosmos-sdk/store/typesb\x06proto3'
)




_STOREKVPAIR = _descriptor.Descriptor(
  name='StoreKVPair',
  full_name='cosmos.base.store.v1beta1.StoreKVPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_key', full_name='cosmos.base.store.v1beta1.StoreKVPair.store_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete', full_name='cosmos.base.store.v1beta1.StoreKVPair.delete', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='cosmos.base.store.v1beta1.StoreKVPair.key', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cosmos.base.store.v1beta1.StoreKVPair.value', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=148,
)

DESCRIPTOR.message_types_by_name['StoreKVPair'] = _STOREKVPAIR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StoreKVPair = _reflection.GeneratedProtocolMessageType('StoreKVPair', (_message.Message,), {
  'DESCRIPTOR' : _STOREKVPAIR,
  '__module__' : 'cosmos.base.store.v1beta1.listening_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.store.v1beta1.StoreKVPair)
  })
_sym_db.RegisterMessage(StoreKVPair)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/capability/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.capability.v1beta1 import capability_pb2 as cosmos_dot_capability_dot_v1beta1_dot_capability__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/capability/v1beta1/genesis.proto',
  package='cosmos.capability.v1beta1',
  syntax='proto3',
  serialized_options=b'Z/github.com/cosmos/cosmos-sdk/x/capability/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'cosmos/capability/v1beta1/genesis.proto\x12\x19\x63osmos.capability.v1beta1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/capability/v1beta1/capability.proto\"~\n\rGenesisOwners\x12\r\n\x05index\x18\x01 \x01(\x04\x12^\n\x0cindex_owners\x18\x02 \x01(\x0b\x32+.cosmos.capability.v1beta1.CapabilityOwnersB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"index_owners\"\"]\n\x0cGenesisState\x12\r\n\x05index\x18\x01 \x01(\x04\x12>\n\x06owners\x18\x02 \x03(\x0b\x32(.cosmos.capability.v1beta1.GenesisOwnersB\x04\xc8\xde\x1f\x00\x42\x31Z/github.com/cosmos/cosmos-sdk/x/capability/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_capability_dot_v1beta1_dot_capability__pb2.DESCRIPTOR,])




_GENESISOWNERS = _descriptor.Descriptor(
  name='GenesisOwners',
  full_name='cosmos.capability.v1beta1.GenesisOwners',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='cosmos.capability.v1beta1.GenesisOwners.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index_owners', full_name='cosmos.capability.v1beta1.GenesisOwners.index_owners', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\362\336\037\023yaml:\"index_owners\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=262,
)


_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='cosmos.capability.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='cosmos.capability.v1beta1.GenesisState.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owners', full_name='cosmos.capability.v1beta1.GenesisState.owners', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=357,
)

_GENESISOWNERS.fields_by_name['index_owners'].message_type = cosmos_dot_capability_dot_v1beta1_dot_capability__pb2._CAPABILITYOWNERS
_GENESISSTATE.fields_by_name['owners'].message_type = _GENESISOWNERS
DESCRIPTOR.message_types_by_name['GenesisOwners'] = _GENESISOWNERS
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisOwners = _reflection.GeneratedProtocolMessageType('GenesisOwners', (_message.Message,), {
  'DESCRIPTOR' : _GENESISOWNERS,
  '__module__' : 'cosmos.capability.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.capability.v1beta1.GenesisOwners)
  })
_sym_db.RegisterMessage(GenesisOwners)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.capability.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.capability.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)


DESCRIPTOR._options = None
_GENESISOWNERS.fields_by_name['index_owners']._options = None
_GENESISSTATE.fields_by_name['owners']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.feegrant.v1beta1 import tx_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the feegrant msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GrantAllowance = channel.unary_unary(
                '/cosmos.feegrant.v1beta1.Msg/GrantAllowance',
                request_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgGrantAllowance.SerializeToString,
                response_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgGrantAllowanceResponse.FromString,
                )
        self.RevokeAllowance = channel.unary_unary(
                '/cosmos.feegrant.v1beta1.Msg/RevokeAllowance',
                request_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgRevokeAllowance.SerializeToString,
                response_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgRevokeAllowanceResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the feegrant msg service.
    """

    def GrantAllowance(self, request, context):
        """GrantAllowance grants fee allowance to the grantee on the granter's
        account with the provided expiration time.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeAllowance(self, request, context):
        """RevokeAllowance revokes any fee allowance of granter's account that
        has been granted to the grantee.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GrantAllowance': grpc.unary_unary_rpc_method_handler(
                    servicer.GrantAllowance,
                    request_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgGrantAllowance.FromString,
                    response_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgGrantAllowanceResponse.SerializeToString,
            ),
            'RevokeAllowance': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeAllowance,
                    request_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgRevokeAllowance.FromString,
                    response_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgRevokeAllowanceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.feegrant.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the feegrant msg service.
    """

    @staticmethod
    def GrantAllowance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.feegrant.v1beta1.Msg/GrantAllowance',
            cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgGrantAllowance.SerializeToString,
            cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgGrantAllowanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeAllowance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.feegrant.v1beta1.Msg/RevokeAllowance',
            cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgRevokeAllowance.SerializeToString,
            cosmos_dot_feegrant_dot_v1beta1_dot_tx__pb2.MsgRevokeAllowanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/reflection/v2alpha1/reflection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/base/reflection/v2alpha1/reflection.proto',
  package='cosmos.base.reflection.v2alpha1',
  syntax='proto3',
  serialized_options=b'Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0cosmos/base/reflection/v2alpha1/reflection.proto\x12\x1f\x63osmos.base.reflection.v2alpha1\x1a\x1cgoogle/api/annotations.proto\"\xb0\x03\n\rAppDescriptor\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\x12?\n\x05\x63hain\x18\x02 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\x12?\n\x05\x63odec\x18\x03 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\x12O\n\rconfiguration\x18\x04 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\x12P\n\x0equery_services\x18\x05 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\x12\x39\n\x02tx\x18\x06 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"^\n\x0cTxDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12<\n\x04msgs\x18\x02 \x03(\x0b\x32..cosmos.base.reflection.v2alpha1.MsgDescriptor\"]\n\x0f\x41uthnDescriptor\x12J\n\nsign_modes\x18\x01 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.SigningModeDescriptor\"b\n\x15SigningModeDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12+\n#authn_info_provider_method_fullname\x18\x03 \x01(\t\"\x1d\n\x0f\x43hainDescriptor\x12\n\n\x02id\x18\x01 \x01(\t\"[\n\x0f\x43odecDescriptor\x12H\n\ninterfaces\x18\x01 \x03(\x0b\x32\x34.cosmos.base.reflection.v2alpha1.InterfaceDescriptor\"\xf4\x01\n\x13InterfaceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12j\n\x1cinterface_accepting_messages\x18\x02 \x03(\x0b\x32\x44.cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor\x12_\n\x16interface_implementers\x18\x03 \x03(\x0b\x32?.cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor\"D\n\x1eInterfaceImplementerDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x10\n\x08type_url\x18\x02 \x01(\t\"W\n#InterfaceAcceptingMessageDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x1e\n\x16\x66ield_descriptor_names\x18\x02 \x03(\t\"@\n\x17\x43onfigurationDescriptor\x12%\n\x1d\x62\x65\x63h32_account_address_prefix\x18\x01 \x01(\t\"%\n\rMsgDescriptor\x12\x14\n\x0cmsg_type_url\x18\x01 \x01(\t\"\x1b\n\x19GetAuthnDescriptorRequest\"]\n\x1aGetAuthnDescriptorResponse\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\"\x1b\n\x19GetChainDescriptorRequest\"]\n\x1aGetChainDescriptorResponse\x12?\n\x05\x63hain\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\"\x1b\n\x19GetCodecDescriptorRequest\"]\n\x1aGetCodecDescriptorResponse\x12?\n\x05\x63odec\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\"#\n!GetConfigurationDescriptorRequest\"n\n\"GetConfigurationDescriptorResponse\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\"#\n!GetQueryServicesDescriptorRequest\"o\n\"GetQueryServicesDescriptorResponse\x12I\n\x07queries\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\"\x18\n\x16GetTxDescriptorRequest\"T\n\x17GetTxDescriptorResponse\x12\x39\n\x02tx\x18\x01 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"j\n\x17QueryServicesDescriptor\x12O\n\x0equery_services\x18\x01 \x03(\x0b\x32\x37.cosmos.base.reflection.v2alpha1.QueryServiceDescriptor\"\x86\x01\n\x16QueryServiceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x11\n\tis_module\x18\x02 \x01(\x08\x12G\n\x07methods\x18\x03 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.QueryMethodDescriptor\">\n\x15QueryMethodDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ull_query_path\x18\x02 \x01(\t2\xa7\n\n\x11ReflectionService\x12\xcb\x01\n\x12GetAuthnDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/authn\x12\xcb\x01\n\x12GetChainDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/chain\x12\xcb\x01\n\x12GetCodecDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/codec\x12\xeb\x01\n\x1aGetConfigurationDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/configuration\x12\xec\x01\n\x1aGetQueryServicesDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cosmos/base/reflection/v1beta1/app_descriptor/query_services\x12\xca\x01\n\x0fGetTxDescriptor\x12\x37.cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest\x1a\x38.cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptorB>Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_APPDESCRIPTOR = _descriptor.Descriptor(
  name='AppDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.AppDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authn', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.authn', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.chain', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.codec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.configuration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_services', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.query_services', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.base.reflection.v2alpha1.AppDescriptor.tx', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=548,
)


_TXDESCRIPTOR = _descriptor.Descriptor(
  name='TxDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.TxDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.TxDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msgs', full_name='cosmos.base.reflection.v2alpha1.TxDescriptor.msgs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=644,
)


_AUTHNDESCRIPTOR = _descriptor.Descriptor(
  name='AuthnDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.AuthnDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sign_modes', full_name='cosmos.base.reflection.v2alpha1.AuthnDescriptor.sign_modes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=739,
)


_SIGNINGMODEDESCRIPTOR = _descriptor.Descriptor(
  name='SigningModeDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor.number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authn_info_provider_method_fullname', full_name='cosmos.base.reflection.v2alpha1.SigningModeDescriptor.authn_info_provider_method_fullname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=839,
)


_CHAINDESCRIPTOR = _descriptor.Descriptor(
  name='ChainDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.ChainDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='cosmos.base.reflection.v2alpha1.ChainDescriptor.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=870,
)


_CODECDESCRIPTOR = _descriptor.Descriptor(
  name='CodecDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.CodecDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interfaces', full_name='cosmos.base.reflection.v2alpha1.CodecDescriptor.interfaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=963,
)


_INTERFACEDESCRIPTOR = _descriptor.Descriptor(
  name='InterfaceDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_accepting_messages', full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor.interface_accepting_messages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_implementers', full_name='cosmos.base.reflection.v2alpha1.InterfaceDescriptor.interface_implementers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=966,
  serialized_end=1210,
)


_INTERFACEIMPLEMENTERDESCRIPTOR = _descriptor.Descriptor(
  name='InterfaceImplementerDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor.type_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1212,
  serialized_end=1280,
)


_INTERFACEACCEPTINGMESSAGEDESCRIPTOR = _descriptor.Descriptor(
  name='InterfaceAcceptingMessageDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_descriptor_names', full_name='cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor.field_descriptor_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1369,
)


_CONFIGURATIONDESCRIPTOR = _descriptor.Descriptor(
  name='ConfigurationDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.ConfigurationDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bech32_account_address_prefix', full_name='cosmos.base.reflection.v2alpha1.ConfigurationDescriptor.bech32_account_address_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1435,
)


_MSGDESCRIPTOR = _descriptor.Descriptor(
  name='MsgDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.MsgDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type_url', full_name='cosmos.base.reflection.v2alpha1.MsgDescriptor.msg_type_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1437,
  serialized_end=1474,
)


_GETAUTHNDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetAuthnDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1503,
)


_GETAUTHNDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetAuthnDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authn', full_name='cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse.authn', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1598,
)


_GETCHAINDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetChainDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=1627,
)


_GETCHAINDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetChainDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain', full_name='cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse.chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1629,
  serialized_end=1722,
)


_GETCODECDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetCodecDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1751,
)


_GETCODECDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetCodecDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec', full_name='cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse.codec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1753,
  serialized_end=1846,
)


_GETCONFIGURATIONDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetConfigurationDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1883,
)


_GETCONFIGURATIONDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetConfigurationDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1885,
  serialized_end=1995,
)


_GETQUERYSERVICESDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetQueryServicesDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1997,
  serialized_end=2032,
)


_GETQUERYSERVICESDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetQueryServicesDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queries', full_name='cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse.queries', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2145,
)


_GETTXDESCRIPTORREQUEST = _descriptor.Descriptor(
  name='GetTxDescriptorRequest',
  full_name='cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2147,
  serialized_end=2171,
)


_GETTXDESCRIPTORRESPONSE = _descriptor.Descriptor(
  name='GetTxDescriptorResponse',
  full_name='cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2173,
  serialized_end=2257,
)


_QUERYSERVICESDESCRIPTOR = _descriptor.Descriptor(
  name='QueryServicesDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.QueryServicesDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_services', full_name='cosmos.base.reflection.v2alpha1.QueryServicesDescriptor.query_services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2259,
  serialized_end=2365,
)


_QUERYSERVICEDESCRIPTOR = _descriptor.Descriptor(
  name='QueryServiceDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullname', full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor.fullname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_module', full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor.is_module', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='methods', full_name='cosmos.base.reflection.v2alpha1.QueryServiceDescriptor.methods', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2368,
  serialized_end=2502,
)


_QUERYMETHODDESCRIPTOR = _descriptor.Descriptor(
  name='QueryMethodDescriptor',
  full_name='cosmos.base.reflection.v2alpha1.QueryMethodDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cosmos.base.reflection.v2alpha1.QueryMethodDescriptor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='full_query_path', full_name='cosmos.base.reflection.v2alpha1.QueryMethodDescriptor.full_query_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2504,
  serialized_end=2566,
)

_APPDESCRIPTOR.fields_by_name['authn'].message_type = _AUTHNDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['chain'].message_type = _CHAINDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['codec'].message_type = _CODECDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['configuration'].message_type = _CONFIGURATIONDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['query_services'].message_type = _QUERYSERVICESDESCRIPTOR
_APPDESCRIPTOR.fields_by_name['tx'].message_type = _TXDESCRIPTOR
_TXDESCRIPTOR.fields_by_name['msgs'].message_type = _MSGDESCRIPTOR
_AUTHNDESCRIPTOR.fields_by_name['sign_modes'].message_type = _SIGNINGMODEDESCRIPTOR
_CODECDESCRIPTOR.fields_by_name['interfaces'].message_type = _INTERFACEDESCRIPTOR
_INTERFACEDESCRIPTOR.fields_by_name['interface_accepting_messages'].message_type = _INTERFACEACCEPTINGMESSAGEDESCRIPTOR
_INTERFACEDESCRIPTOR.fields_by_name['interface_implementers'].message_type = _INTERFACEIMPLEMENTERDESCRIPTOR
_GETAUTHNDESCRIPTORRESPONSE.fields_by_name['authn'].message_type = _AUTHNDESCRIPTOR
_GETCHAINDESCRIPTORRESPONSE.fields_by_name['chain'].message_type = _CHAINDESCRIPTOR
_GETCODECDESCRIPTORRESPONSE.fields_by_name['codec'].message_type = _CODECDESCRIPTOR
_GETCONFIGURATIONDESCRIPTORRESPONSE.fields_by_name['config'].message_type = _CONFIGURATIONDESCRIPTOR
_GETQUERYSERVICESDESCRIPTORRESPONSE.fields_by_name['queries'].message_type = _QUERYSERVICESDESCRIPTOR
_GETTXDESCRIPTORRESPONSE.fields_by_name['tx'].message_type = _TXDESCRIPTOR
_QUERYSERVICESDESCRIPTOR.fields_by_name['query_services'].message_type = _QUERYSERVICEDESCRIPTOR
_QUERYSERVICEDESCRIPTOR.fields_by_name['methods'].message_type = _QUERYMETHODDESCRIPTOR
DESCRIPTOR.message_types_by_name['AppDescriptor'] = _APPDESCRIPTOR
DESCRIPTOR.message_types_by_name['TxDescriptor'] = _TXDESCRIPTOR
DESCRIPTOR.message_types_by_name['AuthnDescriptor'] = _AUTHNDESCRIPTOR
DESCRIPTOR.message_types_by_name['SigningModeDescriptor'] = _SIGNINGMODEDESCRIPTOR
DESCRIPTOR.message_types_by_name['ChainDescriptor'] = _CHAINDESCRIPTOR
DESCRIPTOR.message_types_by_name['CodecDescriptor'] = _CODECDESCRIPTOR
DESCRIPTOR.message_types_by_name['InterfaceDescriptor'] = _INTERFACEDESCRIPTOR
DESCRIPTOR.message_types_by_name['InterfaceImplementerDescriptor'] = _INTERFACEIMPLEMENTERDESCRIPTOR
DESCRIPTOR.message_types_by_name['InterfaceAcceptingMessageDescriptor'] = _INTERFACEACCEPTINGMESSAGEDESCRIPTOR
DESCRIPTOR.message_types_by_name['ConfigurationDescriptor'] = _CONFIGURATIONDESCRIPTOR
DESCRIPTOR.message_types_by_name['MsgDescriptor'] = _MSGDESCRIPTOR
DESCRIPTOR.message_types_by_name['GetAuthnDescriptorRequest'] = _GETAUTHNDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetAuthnDescriptorResponse'] = _GETAUTHNDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetChainDescriptorRequest'] = _GETCHAINDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetChainDescriptorResponse'] = _GETCHAINDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetCodecDescriptorRequest'] = _GETCODECDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetCodecDescriptorResponse'] = _GETCODECDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigurationDescriptorRequest'] = _GETCONFIGURATIONDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetConfigurationDescriptorResponse'] = _GETCONFIGURATIONDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetQueryServicesDescriptorRequest'] = _GETQUERYSERVICESDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetQueryServicesDescriptorResponse'] = _GETQUERYSERVICESDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['GetTxDescriptorRequest'] = _GETTXDESCRIPTORREQUEST
DESCRIPTOR.message_types_by_name['GetTxDescriptorResponse'] = _GETTXDESCRIPTORRESPONSE
DESCRIPTOR.message_types_by_name['QueryServicesDescriptor'] = _QUERYSERVICESDESCRIPTOR
DESCRIPTOR.message_types_by_name['QueryServiceDescriptor'] = _QUERYSERVICEDESCRIPTOR
DESCRIPTOR.message_types_by_name['QueryMethodDescriptor'] = _QUERYMETHODDESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppDescriptor = _reflection.GeneratedProtocolMessageType('AppDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _APPDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.AppDescriptor)
  })
_sym_db.RegisterMessage(AppDescriptor)

TxDescriptor = _reflection.GeneratedProtocolMessageType('TxDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _TXDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.TxDescriptor)
  })
_sym_db.RegisterMessage(TxDescriptor)

AuthnDescriptor = _reflection.GeneratedProtocolMessageType('AuthnDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _AUTHNDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.AuthnDescriptor)
  })
_sym_db.RegisterMessage(AuthnDescriptor)

SigningModeDescriptor = _reflection.GeneratedProtocolMessageType('SigningModeDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINGMODEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.SigningModeDescriptor)
  })
_sym_db.RegisterMessage(SigningModeDescriptor)

ChainDescriptor = _reflection.GeneratedProtocolMessageType('ChainDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CHAINDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.ChainDescriptor)
  })
_sym_db.RegisterMessage(ChainDescriptor)

CodecDescriptor = _reflection.GeneratedProtocolMessageType('CodecDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CODECDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.CodecDescriptor)
  })
_sym_db.RegisterMessage(CodecDescriptor)

InterfaceDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceDescriptor)
  })
_sym_db.RegisterMessage(InterfaceDescriptor)

InterfaceImplementerDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceImplementerDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEIMPLEMENTERDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor)
  })
_sym_db.RegisterMessage(InterfaceImplementerDescriptor)

InterfaceAcceptingMessageDescriptor = _reflection.GeneratedProtocolMessageType('InterfaceAcceptingMessageDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACEACCEPTINGMESSAGEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor)
  })
_sym_db.RegisterMessage(InterfaceAcceptingMessageDescriptor)

ConfigurationDescriptor = _reflection.GeneratedProtocolMessageType('ConfigurationDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURATIONDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.ConfigurationDescriptor)
  })
_sym_db.RegisterMessage(ConfigurationDescriptor)

MsgDescriptor = _reflection.GeneratedProtocolMessageType('MsgDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _MSGDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.MsgDescriptor)
  })
_sym_db.RegisterMessage(MsgDescriptor)

GetAuthnDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetAuthnDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHNDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest)
  })
_sym_db.RegisterMessage(GetAuthnDescriptorRequest)

GetAuthnDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetAuthnDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHNDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse)
  })
_sym_db.RegisterMessage(GetAuthnDescriptorResponse)

GetChainDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetChainDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest)
  })
_sym_db.RegisterMessage(GetChainDescriptorRequest)

GetChainDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetChainDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHAINDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse)
  })
_sym_db.RegisterMessage(GetChainDescriptorResponse)

GetCodecDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetCodecDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCODECDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest)
  })
_sym_db.RegisterMessage(GetCodecDescriptorRequest)

GetCodecDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetCodecDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCODECDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse)
  })
_sym_db.RegisterMessage(GetCodecDescriptorResponse)

GetConfigurationDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetConfigurationDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest)
  })
_sym_db.RegisterMessage(GetConfigurationDescriptorRequest)

GetConfigurationDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetConfigurationDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse)
  })
_sym_db.RegisterMessage(GetConfigurationDescriptorResponse)

GetQueryServicesDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetQueryServicesDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSERVICESDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest)
  })
_sym_db.RegisterMessage(GetQueryServicesDescriptorRequest)

GetQueryServicesDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetQueryServicesDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYSERVICESDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse)
  })
_sym_db.RegisterMessage(GetQueryServicesDescriptorResponse)

GetTxDescriptorRequest = _reflection.GeneratedProtocolMessageType('GetTxDescriptorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXDESCRIPTORREQUEST,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest)
  })
_sym_db.RegisterMessage(GetTxDescriptorRequest)

GetTxDescriptorResponse = _reflection.GeneratedProtocolMessageType('GetTxDescriptorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXDESCRIPTORRESPONSE,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse)
  })
_sym_db.RegisterMessage(GetTxDescriptorResponse)

QueryServicesDescriptor = _reflection.GeneratedProtocolMessageType('QueryServicesDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSERVICESDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryServicesDescriptor)
  })
_sym_db.RegisterMessage(QueryServicesDescriptor)

QueryServiceDescriptor = _reflection.GeneratedProtocolMessageType('QueryServiceDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSERVICEDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryServiceDescriptor)
  })
_sym_db.RegisterMessage(QueryServiceDescriptor)

QueryMethodDescriptor = _reflection.GeneratedProtocolMessageType('QueryMethodDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMETHODDESCRIPTOR,
  '__module__' : 'cosmos.base.reflection.v2alpha1.reflection_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.reflection.v2alpha1.QueryMethodDescriptor)
  })
_sym_db.RegisterMessage(QueryMethodDescriptor)


DESCRIPTOR._options = None

_REFLECTIONSERVICE = _descriptor.ServiceDescriptor(
  name='ReflectionService',
  full_name='cosmos.base.reflection.v2alpha1.ReflectionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2569,
  serialized_end=3888,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAuthnDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetAuthnDescriptor',
    index=0,
    containing_service=None,
    input_type=_GETAUTHNDESCRIPTORREQUEST,
    output_type=_GETAUTHNDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/authn',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChainDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetChainDescriptor',
    index=1,
    containing_service=None,
    input_type=_GETCHAINDESCRIPTORREQUEST,
    output_type=_GETCHAINDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/chain',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCodecDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetCodecDescriptor',
    index=2,
    containing_service=None,
    input_type=_GETCODECDESCRIPTORREQUEST,
    output_type=_GETCODECDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/codec',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfigurationDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetConfigurationDescriptor',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGURATIONDESCRIPTORREQUEST,
    output_type=_GETCONFIGURATIONDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/configuration',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetQueryServicesDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetQueryServicesDescriptor',
    index=4,
    containing_service=None,
    input_type=_GETQUERYSERVICESDESCRIPTORREQUEST,
    output_type=_GETQUERYSERVICESDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\002?\022=/cosmos/base/reflection/v1beta1/app_descriptor/query_services',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxDescriptor',
    full_name='cosmos.base.reflection.v2alpha1.ReflectionService.GetTxDescriptor',
    index=5,
    containing_service=None,
    input_type=_GETTXDESCRIPTORREQUEST,
    output_type=_GETTXDESCRIPTORRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptor',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REFLECTIONSERVICE)

DESCRIPTOR.services_by_name['ReflectionService'] = _REFLECTIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2018-2022 Fetch.AI Limited
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------
"""Implementation of Gov interface using REST."""

from google.protobuf.json_format import Parse

from cosmpy.common.rest_client import RestClient
from cosmpy.gov.interface import Gov
from cosmpy.protos.cosmos.gov.v1beta1.query_pb2 import (
    QueryDepositRequest,
    QueryDepositResponse,
    QueryDepositsRequest,
    QueryDepositsResponse,
    QueryParamsRequest,
    QueryParamsResponse,
    QueryProposalRequest,
    QueryProposalResponse,
    QueryProposalsRequest,
    QueryProposalsResponse,
    QueryTallyResultRequest,
    QueryTallyResultResponse,
    QueryVoteRequest,
    QueryVoteResponse,
    QueryVotesRequest,
    QueryVotesResponse,
)


class GovRestClient(Gov):
    """Gov REST client."""

    API_URL = "/cosmos/gov/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Proposal(self, request: QueryProposalRequest) -> QueryProposalResponse:
        """
        Proposal queries proposal details based on ProposalID.

        :param request: QueryProposalRequest with proposal id

        :return: QueryProposalResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/proposals/{request.proposal_id}",
        )
        return Parse(json_response, QueryProposalResponse())

    def Proposals(self, request: QueryProposalsRequest) -> QueryProposalsResponse:
        """
        Proposals queries all proposals based on given status.

        :param request: QueryProposalsRequest

        :return: QueryProposalsResponse
        """

        json_response = self._rest_api.get(
            f"{self.API_URL}/proposals/",
            request,
        )
        return Parse(json_response, QueryProposalsResponse())

    def Vote(self, request: QueryVoteRequest) -> QueryVoteResponse:
        """
        Vote queries voted information based on proposalID, voterAddr.

        :param request: QueryVoteRequest with voter and proposal id

        :return: QueryVoteResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/proposals/{request.proposal_id}/votes/{request.voter}"
        )
        return Parse(json_response, QueryVoteResponse())

    def Votes(self, request: QueryVotesRequest) -> QueryVotesResponse:
        """
        Votes queries votes of a given proposal.

        :param request: QueryVotesResponse with proposal id

        :return: QueryVotesResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/proposals/{request.proposal_id}/votes/",
            request,
            ["proposalID"],
        )
        return Parse(json_response, QueryVotesResponse())

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Params queries all parameters of the gov module.

        :param request: QueryParamsRequest with params_type

        :return: QueryParamsResponse
        """

        json_response = self._rest_api.get(
            f"{self.API_URL}/params/{request.params_type}"
        )
        return Parse(json_response, QueryParamsResponse())

    def Deposit(self, request: QueryDepositRequest) -> QueryDepositResponse:
        """
        Deposit queries single deposit information based proposalID, depositAddr.

        :param request: QueryDepositRequest with depositor and proposal_id

        :return: QueryDepositResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/proposals/{request.proposal_id}/deposits/{request.depositor}"
        )
        return Parse(json_response, QueryDepositResponse())

    def Deposits(self, request: QueryDepositsRequest) -> QueryDepositsResponse:
        """Deposits queries all deposits of a single proposal.

        :param request: QueryDepositsRequest with proposal_id

        :return: QueryDepositsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/proposals/{request.proposal_id}/deposits/",
            request,
            ["proposalID"],
        )
        return Parse(json_response, QueryDepositsResponse())

    def TallyResult(self, request: QueryTallyResultRequest) -> QueryTallyResultResponse:
        """
        Tally Result queries the tally of a proposal vote.

        :param request: QueryTallyResultRequest with proposal_id

        :return: QueryTallyResultResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/proposals/{request.proposal_id}/tally"
        )
        return Parse(json_response, QueryTallyResultResponse())



# -*- coding: utf-8 -*-
# ------------------------------------------------------------------------------
#
#   Copyright 2018-2022 Fetch.AI Limited
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# ------------------------------------------------------------------------------
"""Tests for REST implementation of Evidence."""
import json
from typing import Dict, Tuple
from unittest import TestCase

from google.protobuf.json_format import ParseDict
from google.protobuf.wrappers_pb2 import (  # noqa  # needed for protobuf decode
    Int32Value,
)

from cosmpy.evidence.rest_client import EvidenceRestClient
from cosmpy.protos.cosmos.evidence.v1beta1.query_pb2 import (
    QueryAllEvidenceRequest,
    QueryAllEvidenceResponse,
    QueryEvidenceRequest,
    QueryEvidenceResponse,
)
from tests.helpers import MockRestClient


class EvidenceRestClientTestCase(TestCase):
    """Test case for EvidenceRestClient class."""

    REST_CLIENT = EvidenceRestClient

    def make_clients(
        self, response_content: Dict
    ) -> Tuple[MockRestClient, EvidenceRestClient]:
        """
        Make  mock client and rest client api for specific content.

        :param response_content: dict
        :return: rest client instance
        """
        mock_client = MockRestClient(json.dumps(response_content).encode("utf-8"))
        rest_client = self.REST_CLIENT(mock_client)
        return mock_client, rest_client

    def test_Evidence(self):
        """Test Evidence method."""
        content = {
            "evidence": {
                "@type": "type.googleapis.com/google.protobuf.Int32Value",
                "value": "42",
            }
        }
        mock_client, evidence = self.make_clients(content)
        expected_response = ParseDict(content, QueryEvidenceResponse())

        assert (
            evidence.Evidence(QueryEvidenceRequest(evidence_hash=b"hash"))
            == expected_response
        )
        assert mock_client.last_base_url == "/cosmos/evidence/v1beta1/evidence/b'hash'"

    def test_AllEvidence(self):
        """Test AllEvidence method."""
        content = {
            "evidence": [
                {
                    "@type": "type.googleapis.com/google.protobuf.Int32Value",
                    "value": "42",
                }
            ],
            "pagination": {"next_key": "string", "total": "1"},
        }
        mock_client, evidence = self.make_clients(content)
        expected_response = ParseDict(content, QueryAllEvidenceResponse())

        assert evidence.AllEvidence(QueryAllEvidenceRequest()) == expected_response
        assert mock_client.last_base_url == "/cosmos/evidence/v1beta1/evidence"
